aboutsummaryrefslogtreecommitdiff
path: root/src/who.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/who.rs')
-rw-r--r--src/who.rs4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/who.rs b/src/who.rs
index 9d6e5b5..32f536b 100644
--- a/src/who.rs
+++ b/src/who.rs
@@ -1,4 +1,6 @@
-#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
+use serde::{Deserialize, Serialize};
+
+#[derive(Debug, Default, Clone, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize)]
pub struct Who {
name: String,
}